@@ -54,6 +54,7 @@ def datetimeformat(environment, value, to_format="%Y-%m-%d", from_format="%Y-%m-
 @pass_environment
 def extract_refs(environment, value):
     m = re.findall("@([a-zA-Z0-9_]+)", value)
+    _LOGGER.debug(f"Extracted refs: {m}")
     return m
 
 
@@ -197,32 +198,33 @@ def load_template(cfg):
     if "jinja_template" not in cfg or not cfg["jinja_template"]:
         return None
 
-    md_tpl = None
+    jinja_tpl = None
     root = cfg["mm_templates"] if "mm_templates" in cfg else None
-    md_tpl = make_abspath(cfg["jinja_template"], cfg["_cfg_file_path"], root)
-    _LOGGER.info(f"MM | jinja template: {md_tpl}")
+    jinja_tpl = make_abspath(cfg["jinja_template"], cfg["_cfg_file_path"], root)
+    _LOGGER.info(f"MM | jinja template: {jinja_tpl}")
     # # if os.path.isfile(cfg["md_template"]):
-    # #     md_tpl = cfg["md_template"]
+    # #     jinja_tpl = cfg["md_template"]
     # if "mm_templates" in cfg:
-    #     md_tpl = os.path.join(cfg["mm_templates"], cfg["md_template"])
+    #     jinja_tpl = os.path.join(cfg["mm_templates"], cfg["md_template"])
     # else:
-    #     md_tpl = os.path.join(, cfg["md_template"])
-    if not os.path.isfile(md_tpl):
-        _LOGGER.debug(cfg)
-        raise Exception(f"jinja_template file not found: {md_tpl}")
+    #     jinja_tpl = os.path.join(, cfg["md_template"])
 
     try:
-        if is_url(md_tpl):
+        if is_url(jinja_tpl):
             import requests
 
-            response = requests.get(md_tpl)
-            md_tpl_contents = response.text
+            response = requests.get(jinja_tpl)
+            jinja_tpl_contents = response.text
         else:
-            with open(md_tpl, "r") as f:
-                md_tpl_contents = f.read()
-        t = Template(md_tpl_contents)
+            if not os.path.isfile(jinja_tpl):
+                _LOGGER.debug(cfg)
+                raise Exception(f"jinja_template file not found: {jinja_tpl}")
+
+            with open(jinja_tpl, "r") as f:
+                jinja_tpl_contents = f.read()
+        t = Template(jinja_tpl_contents)
     except TypeError:
-        _LOGGER.error(f"Unable to open jinja_template. Path:{md_tpl}")
+        _LOGGER.error(f"Unable to open jinja_template. Path:{jinja_tpl}")
     return t
 
 
@@ -248,7 +250,7 @@ class Target(object):
         meta["today"] = meta["_today"]  # TODO: Remove this
         meta["now"] = meta["_now"]  # TODO: Remove this
 
-        # Since a target has available to it all the variables in the _markemeld.yaml
+        # Since a target has available to it all the variables in the _markmeld.yaml
         # config file, we start from there, then make a few changes:
         # 1. Elevate the variables in the given target up one level.
         # 2. To simplify debugging and reduce memory, remove the 'targets' key
@@ -258,19 +260,14 @@ class Target(object):
 
         if target_name:
             if "targets" not in root_cfg:
-                _LOGGER.error(f"No targets specified in config.")
-                raise TargetError(f"No targets specified in config.")
+                error_msg = f"No targets specified in config."
+                _LOGGER.error(error_msg)
+                raise TargetError(error_msg)
             if target_name not in list(root_cfg["targets"].keys()):
-                _LOGGER.error(f"target {target_name} not found")
-                raise TargetError(f"Target {target_name} not found")
-            if "inherit_from" in root_cfg["targets"][target_name]:
-                inherit_from = root_cfg["targets"][target_name]["inherit_from"]
-                if type(inherit_from) is not list:
-                    inherit_from = [inherit_from]
-                for base_target in inherit_from:
-                    _LOGGER.info(f"Loading from base target: {base_target}")
-                    meta = deep_update(meta, root_cfg["targets"][base_target])
-            meta = deep_update(meta, root_cfg["targets"][target_name])
+                error_msg = f"Target {target_name} not found"
+                _LOGGER.error(error_msg)
+                raise TargetError(error_msg)
+            meta = deep_update(meta, self.resolve_target_inheritance(target_name))
             _LOGGER.debug(f'Config for this target: {root_cfg["targets"][target_name]}')
 
         # del meta["targets"]
@@ -301,29 +298,41 @@ class Target(object):
         if "output_file" in self.meta:
             _LOGGER.info(f"MM | Output file: {self.meta['output_file']}")
 
+    def __repr__(self):
+        return yaml.dump(self.__dict__["meta"], default_flow_style=False)
+        # import json
+        # return json.dumps(self.__dict__, sort_keys=True, indent=4)
 
-def build_side_targets(tgt, side_list_key="prebuild"):
-    """
-    Builds side targets for a target, which are prebuilds or postbuilds.
+    def resolve_target_inheritance(self, target_name):
+        root_cfg = self.root_cfg
+        if "targets" not in root_cfg:
+            error_msg = f"No targets specified in config."
+            _LOGGER.debug(error_msg)
+            return {}
+        if target_name not in list(root_cfg["targets"].keys()):
+            error_msg = f"Target {target_name} not found"
+            _LOGGER.debug(error_msg)
+            return {}
+        print(root_cfg["targets"])
 
-    Side targets accompany a target, are built either before (prebuild)
-    or after (postbuild) a main target.
+        if "inherit_from" not in root_cfg["targets"][target_name]:
+            ## base case
+            return root_cfg["targets"][target_name]
+        else:
+            ## recurse
+            accumulated = {}
+            # root_cfg["targets"][target_name]
+            inherit_from = root_cfg["targets"][target_name]["inherit_from"]
+            # del accumulated["inherit_from"]
+            if type(inherit_from) is not list:
+                inherit_from = [inherit_from]
+            for base_target in inherit_from:
+                _LOGGER.info(f"Loading from base target: {base_target}")
+                base_target_data = self.resolve_target_inheritance(base_target)
+                accumulated = deep_update(accumulated, base_target_data)
 
-    @param tgt Target The main target to build
-    @param side_list_key Iterable[str] The key of the target that contains a list of side targets. e.g. "prebuild" or "postbuild"
-    """
-    if side_list_key in tgt.meta:
-        _LOGGER.info(f"MM | Run {side_list_key} for target: {tgt.target_name}")
-        for side_tgt in tgt.meta[side_list_key]:
-            _LOGGER.info(f"MM | {side_list_key} target: {side_tgt}")
-            if side_tgt in self.cfg["targets"]:
-                self.build_target(side_tgt)
-            else:
-                _LOGGER.warning(
-                    f"MM | No target called {side_tgt}, requested prebuild by target {tgt}."
-                )
-                return False
-    return True
+            accumulated = deep_update(accumulated, root_cfg["targets"][target_name])
+            return accumulated
 
 
 class MarkdownMelder(object):
@@ -343,13 +352,18 @@ class MarkdownMelder(object):
         else:
             return False
 
-    def build_target(self, target_name, print_only=False, vardump=False):
+    def describe_target(self, target_name):
+        tgt = Target(self.cfg, target_name)
+        _LOGGER.info(f"MM | Describing target: {tgt.target_name}")
+        _LOGGER.info(tgt)
+        return True
 
+    def build_target(self, target_name, print_only=False, vardump=False):
         tgt = Target(self.cfg, target_name)
         _LOGGER.info(f"MM | Building target: {tgt.target_name}")
 
         # First, run any pre-builds
-        if not build_side_targets(tgt, "prebuild"):
+        if not self.build_side_targets(tgt, "prebuild"):
             return False
 
         # Next, meld the inputs. This can be time-consuming, it reads data to populate variables
@@ -362,11 +376,34 @@ class MarkdownMelder(object):
         result = self.run_command_for_target(tgt, print_only, vardump)
 
         # Finally, run any postbuilds
-        if not build_side_targets(tgt, "postbuild"):
+        if not self.build_side_targets(tgt, "postbuild"):
             return False
 
         return result
 
+    def build_side_targets(self, tgt, side_list_key="prebuild"):
+        """
+        Builds side targets for a target, which are prebuilds or postbuilds.
+
+        Side targets accompany a target, are built either before (prebuild)
+        or after (postbuild) a main target.
+
+        @param tgt Target The main target to build
+        @param side_list_key Iterable[str] The key of the target that contains a list of side targets. e.g. "prebuild" or "postbuild"
+        """
+        if side_list_key in tgt.meta:
+            _LOGGER.info(f"MM | Run {side_list_key} for target: {tgt.target_name}")
+            for side_tgt in tgt.meta[side_list_key]:
+                _LOGGER.info(f"MM | {side_list_key} target: {side_tgt}")
+                if side_tgt in self.cfg["targets"]:
+                    self.build_target(side_tgt)
+                else:
+                    _LOGGER.warning(
+                        f"MM | No target called {side_tgt}, requested prebuild by target {tgt}."
+                    )
+                    return False
+        return True
+
     def run_command_for_target(self, tgt, print_only, vardump=False):
 
         _LOGGER.info(f"File path for this target: {tgt.meta['_filepath']}")
@@ -391,9 +428,14 @@ class MarkdownMelder(object):
             cmd_fmt = format_command(tgt)
             _LOGGER.debug(cmd_fmt)
             tgt.melded_output = self.render_template(tgt.melded_input, tgt)
-            tgt.returncode = run_cmd(
-                cmd_fmt, tgt.melded_output.encode(), tgt.meta["_filepath"]
-            )
+            _LOGGER.debug(f"melded_output: '{tgt.melded_output}'")
+            if tgt.melded_output == "" or tgt.melded_output == None:
+                _LOGGER.error("No input detected. Check variable names")
+                tgt.returncode = 2
+            else:
+                tgt.returncode = run_cmd(
+                    cmd_fmt, tgt.melded_output.encode(), tgt.meta["_filepath"]
+                )
         return tgt
 
     def build_target_in_loop(self, tgt, print_only=False, vardump=False):
